# Bitcoin Keygen

Bitcoin Keygen is a minimalistic Pure Python script with Bitcoin utility functions.

## Installation

Bitcoin Keygen can be installed with `pip install bitcoin-keygen` (Python 3.6+ Required).

## Features

- Generate and verify private keys for use on the Bitcoin Blockchain.
- Generate the public key, address and WIF associated with a private key.
- Base58Check encoding, decoding and checksum check utility functions.

Bitcoin Keygen can accept optional parameters as well to work with compressed keys and the testnet.

## License

[GNU General Public License v3.0](LICENSE) (c) 2019 Cheran Senthilkumar
